@@ -36,16 +36,17 @@ sub createSourceTarball() {
 			$doCheckout = 0;
 		}
 		else {
-			system("rm -r $targetSourceDir");
+			system("rm -rf $targetSourceDir");
 		}
 	}
 	if ($doCheckout) {
-		print "Getting the svn version\n";
-		(system("svn export https://svn.code.sf.net/p/packagesearch/code/trunk/packagesearch $targetSourceDir")==0)
-			|| die("Could not get svn version.\n");
+		print "Cloning git version\n";
+		(system("git clone ./ $targetSourceDir")==0)
+			|| die("Could not clone git version.\n");
 	}
 	print "creating source tarball $src_filename \n";
-	(system("GZIP=-9 tar czf $src_filename $targetSourceDir\n")==0) || die("Could not create archive.\n");
+	`rm -rf $targetSourceDir/.git`;
+	(system("GZIP=-9 tar -C $releaseDir -czf ../$src_filename $headmodule-$version\n")==0) || die("Could not create archive.\n");
 	print "source tarball $src_filename created\n";
 
 	
