@@ -8,22 +8,28 @@
 #include <string>
 #include <set>
 
+class QNetworkAccessManager;
 class QPushButton;
 class QStatusBar;
 class QWidget;
 
+namespace Xapian {
+	class Database;
+}
+
 namespace ept 
 {
 	namespace apt {
 		class Apt;
 	}
 	namespace debtags {
-		class Debtags;
 		class Vocabulary;
 	}
-	namespace textsearch {
-		class TextSearch;
-	}
+}
+
+namespace Xapian 
+{
+	class Database;
 }
 
 using namespace std;
@@ -111,12 +117,15 @@ public:
 	
 	/** Returns a reference to the apt object. */
 	virtual const ept::apt::Apt& apt() const = 0;
-	/** Returns a reference to the debtags object. */
-	virtual const ept::debtags::Debtags& debtags() const = 0;
-	/** Returns a reference to the debtags object. */
-	virtual const ept::textsearch::TextSearch& textsearch() const = 0;
+	/** Returns a reference to the debtags vocabulary object. */
+	virtual const ept::debtags::Vocabulary& vocabulary() const = 0;
+	/** Returns a reference to the apt-xapian database. */
+	virtual const Xapian::Database& xapian() const = 0;
 
-	/** @brief Reloads the global apt-front cache. */
+	/** @brief Returns the central network manager which can be used to access the network. */
+	virtual QNetworkAccessManager* network() = 0;
+	
+	/** @brief Reloads the package database. */
 	virtual void reloadAptFrontCache() = 0;
 };
 
