@@ -78,13 +78,15 @@ int main(int argc, char* argv[])
 	
 	QApplication a(argc, argv);
 	
+	// TODO: this makes packagesearch not finding the translations if there is a translations directory anywhere
+	// replace by search for the concrete translation files
 	// setup translation
 	QDir translationDir;
-	if ( QDir("../translations").exists() )
+	if ( QFile("../translations/packagesearch_de.qm").exists() )
 		translationDir = "../translations/";
-	else if ( QDir("translations/").exists() )
+	else if ( QFile("../translations/packagesearch_de.qm").exists() )
 		translationDir = "translations/";
-	else if ( QDir("/usr/share/packagesearch/translations/").exists() )
+	else if ( QFile("../translations/packagesearch_de.qm").exists() )
 		translationDir = "/usr/share/packagesearch/translations";
 	else
 		qWarning("Unable to locate translation directory, translations must be located in "
