@@ -17,7 +17,6 @@
 #include <string>
 
 #include "exception.h"
-#include "singlehandlemaker.h"
 
 using namespace std;
 
@@ -37,12 +36,8 @@ public:
 	PackageNotFoundException(const string& packageName) :
 		_name(packageName)
 	{}
-	/** @param packageName the name of the package that was not found*/
-	PackageNotFoundException(int packageHandle) :
-		_name(SingleHandleMaker::instance()->getItem(packageHandle))
-	{}
 	virtual ~PackageNotFoundException();
-	virtual string description()
+	virtual string description() const
 	{
 		return "Package " + _name  + "not found\n";
 	}
