@@ -260,7 +260,7 @@ void PackageSearchImpl::initialize()
 	do 
 	{
 		try {
-			_pXapianDatabase = new Xapian::Database(ept::axi::path_db());
+			_pXapianDatabase = new Xapian::Database("/var/lib/apt-xapian-index/index");
 			success = true;
 		} catch (Xapian::RuntimeError& e) {
 			if ( QMessageBox::critical(this, tr("Error trying to open Xapian database"), 
