@@ -27,6 +27,8 @@
 
 // NBrowser
 #include "history.h"
+#include "networksettings.h"
+
 
 class QCloseEvent;
 class QDir;
@@ -118,6 +120,7 @@ public:
 	const ept::apt::Apt& apt() const { return *_pApt; }
 	const ept::debtags::Vocabulary& vocabulary() const { return *_pVocabulary; }
 	const Xapian::Database& xapian() const { return *_pXapianDatabase; }
+	virtual QNetworkAccessManager* network();
 	//@}
 	/** @name IPluginUser interface
 	  *
@@ -347,6 +350,7 @@ private:
 	NPlugin::ScoreDisplayPlugin* _pScoreDisplayPlugin;
 	/** @brief Timer used to periodically call checkAptDbForUpdates(). */
 	QTimer timer;
+	NUtil::NetworkSettings _network;
 };
 
 #endif // __PACKAGESEARCHIMPL_H_2004_03_21
