@@ -14,6 +14,9 @@
 #include <ept/apt/packagerecord.h>
 #include <ept/apt/apt.h>
 
+#include <apt-pkg/pkgcache.h>
+#include <apt-pkg/pkgrecords.h>
+
 namespace NApt 
 {
 
@@ -27,6 +30,7 @@ AptFrontPackage::AptFrontPackage(const ept::apt::Apt& pApt, const std::string& s
 
 AptFrontPackage::~AptFrontPackage()
 {
+	delete m_rec;
 }
 
 const ept::apt::PackageRecord& AptFrontPackage::rec() const
@@ -154,9 +158,31 @@ QString AptFrontPackage::conffiles() const
 
 QString AptFrontPackage::description() const
 {
-	return toQString(rec().longDescription(string()));
+	// source code taken from libapt, and slightly adapted
+	pkgCache* pPkgCache = const_cast<pkgCache*>(_pApt->aptPkgCache());
+	pkgCache::PkgIterator pi = pPkgCache->FindPkg(toString(name()));
+	if (pi.end()) 
+		return QString();
+	for (pkgCache::VerIterator vi = pi.VersionList(); !vi.end(); vi++)
+	{
+		const char* v = vi.VerStr();
+		if (v == 0) continue;
+		if (rec().version() != v) continue;
+
+		// Get the translated record
+		pkgRecords Recs(*pPkgCache);
+		pkgCache::DescIterator Desc = vi.TranslatedDescription();
+		pkgRecords::Parser &P = Recs.Lookup(Desc.FileList());
+		// TODO currently the language code is not added here
+		// this would break the packagerecord parsing algorithm, should be implemented
+		// in the future though
+		//result << "Description" << ( (strcmp(Desc.LanguageCode(),"") != 0) ? "-" : "" ) << Desc.LanguageCode() << ": " << P.LongDesc();
+		return toQString(P.LongDesc());
+	}
+	return QString();
 }
 
+
 AptFrontPackage::InstalledState AptFrontPackage::installedState() const
 {
 	ept::apt::PackageState state = _pApt->state(_source);
@@ -178,6 +204,11 @@ QString AptFrontPackage::shortDescription() const
 	return toQString(rec().shortDescription(string()));;
 }
 
+QString AptFrontPackage::homepage() const 
+{
+	return toQString(rec().lookup("Homepage"));
+}
+
 /*
 QString AptFrontPackage::getRelation(Relation::Type type) const
 {
