@@ -21,6 +21,11 @@ using namespace std;
 class QStringList;
 class QString;
 
+namespace NUtil
+{
+	class IProgressObserver;
+}
+
 namespace NApt {
 
 /**
@@ -67,6 +72,11 @@ public:
 	  */
 	virtual bool search(std::set<string>& result, const QString& pattern, 
 		bool searchDescr) const = 0;
+		
+	/** @brief This reloads the package information search upon. 
+	  * @param pLoader the observer where to report the reload progress, 0 if no progress should be reported  
+	  */
+	virtual void reloadPackageInformation(NUtil::IProgressObserver* pObserver) = 0;
 };
 
 };
