@@ -71,6 +71,7 @@ Package::Package(const IPackage& package)
 	_installedVersion = package.installedVersion();
 	_installedState = package.installedState();
 	_shortDescription = package.shortDescription();
+	_homepage = package.homepage();
 }
 
 
@@ -114,6 +115,7 @@ void Package::parseInformation(const QStringList& lines)
 		sectionToString["MD5sum"]=&_md5sum - &_name;
 		sectionToString["Conffiles"]=&_conffiles - &_name;
 		sectionToString["Description"]=&_description - &_name;
+		sectionToString["Homepage"]=&_homepage - &_name;
 	
 // 		sectionToString["InstalledVersion"]=&installedVersion - &package;
 
