@@ -14,7 +14,6 @@
 #define __NAPT_PACKAGE_H_2005_02_19
 
 #include <qstring.h>
-#include <q3cstring.h>
 
 #include <ipackage.h>
 
@@ -60,9 +59,10 @@ struct Package : public IPackage
 	QString _conffiles;
 	QString _description;
 	InstalledState _installedState;
-	Q3CString _installedVersion;
+	QString _installedVersion;
 	/** This should be filled with the first line of the description. */
-	Q3CString _shortDescription;
+	QString _shortDescription;
+	QString _homepage;
 	
 	virtual QString name() const { return _name; }
 	virtual QString essential() const { return _essential; }
@@ -86,8 +86,9 @@ struct Package : public IPackage
 	virtual QString conffiles() const { return _conffiles; }
 	virtual QString description() const { return _description; }
 	virtual InstalledState installedState() const { return _installedState; }
-	virtual QString installedVersion() const { return QString(_installedVersion); }
-	virtual QString shortDescription() const { return QString(_shortDescription); }
+	virtual QString installedVersion() const { return _installedVersion; }
+	virtual QString shortDescription() const { return _shortDescription; }
+	virtual QString homepage() const { return _homepage; }
 
 	
 	virtual uint getSize() const 	{ return _size.toUInt(); }
@@ -134,6 +135,7 @@ void Package::processEntries(T& t)
 	t(_md5sum);
 	t(_conffiles);
 	t(_description);
+	t(_homepage);
 }
 
 
