@@ -24,7 +24,8 @@ PackageStatusPlugin::PackageStatusPlugin(NApt::IPackageDB* pPackageDB) :
 	_pPackageDB(pPackageDB)
 { 
 	_pInstalledFilterWidget = 0;
-	_stateToText[NApt::Package::INSTALLED] = "x";
+	_stateToText[NApt::Package::INSTALLED] = "i";
+	_stateToText[NApt::Package::UPGRADABLE] = "u";
 	_stateToText[NApt::Package::NOT_INSTALLED] = "";
 }
 
@@ -62,8 +63,11 @@ bool PackageStatusPlugin::filterPackage(const string& package) const
 {
 	try 
 	{
-		NApt::Package::InstalledState state = getState(package);
-		return _installedFilter == (InstalledState) state;	// does the state of the package match the on filtered by?
+		NApt::IPackage::InstalledState state = getState(package);
+		if (_installedFilter == INSTALLED)
+			return state == NApt::IPackage::INSTALLED || state == NApt::IPackage::UPGRADABLE;
+		else
+			return _installedFilter == (InstalledState) state;	// does the state of the package match the on filtered by?
 	}
 	catch (const PackageNotFoundException& e)	// if the package is not in the database, it is not installed
 	{
@@ -120,6 +124,9 @@ void PackageStatusPlugin::onInstalledFilterChanged(int activated)
 			_installedFilter = INSTALLED;
 			break;
 		case 2:
+			_installedFilter = UPGRADABLE;
+			break;
+		case 3:
 			_installedFilter = NOT_INSTALLED;
 			break;
 	}
