@@ -64,18 +64,8 @@ public:
 	virtual ~EmptyTagFilter();
 	virtual bool filterAcceptsRow(int sourceRow, const QModelIndex& sourceParent) const;
 
-public slots:
+public Q_SLOTS:
 	void tagSelectionChanged();
-private slots:
-	/** @brief This slot is connected to a single shot timer, which is started when
-	 * the tag selection has changed.
-	 *	
-	 * It calls filterChanged(). The usage of a timer was neccessary, because QT seems not to
-	 * gracefully accept, when filterChanged() is called directly during the evaluation of
-	 * filters themselves. 
-	 *
-	 */
-	void onSelectionChangedTimeout();
 
 };
 
