@@ -12,7 +12,6 @@
 #undef slots
 #include <xapian.h>
 
-#include <tagcoll/utils/set.h>
 #include <ept/debtags/debtags.h>
 
 // NUtil
@@ -235,4 +234,3 @@ void RelatedPlugin::setWidgetsEnabled(bool enabled)
 }	// namespace NPlugin
 
 #undef emit
-#include <ept/debtags/debtags.tcc>
