@@ -35,8 +35,8 @@ using namespace wibble::operators;
 namespace NWidgets 
 {
 
-typedef ept::debtags::Facet Facet;
-typedef ept::debtags::Tag Tag;
+typedef std::string Facet;
+typedef std::string Tag;
 
 
 SelectionInputAndDisplay::SelectionInputAndDisplay(const NPlugin::DebtagsPluginContainer* pContainer, NTagModel::VocabularyModel* pModel, QObject* pParent)
