@@ -12,6 +12,8 @@
 #ifndef __NPLUGIN_FILENAMEACTIONPLUGIN_H_2005_09_01
 #define __NPLUGIN_FILENAMEACTIONPLUGIN_H_2005_09_01
 
+#include <QObject>
+
 #include <actionplugin.h>
 
 namespace NPlugin {
@@ -22,9 +24,8 @@ namespace NPlugin {
 Currently the only action offered is used to perform apt-file update.
  * @author Benjamin Mesing
   */
-class FilenameActionPlugin : public ActionPlugin
+class FilenameActionPlugin : public QObject, public ActionPlugin
 {
-Q_OBJECT
 	const QString _title;
 	const QString _briefDescription;
 	const QString _description;
