@@ -3,6 +3,8 @@
 
 #include <string>
 
+#include <QFileInfo>
+#include <QObject>
 #include <qstring.h>
 #include <qstringlist.h>
 #include <qmutex.h>
@@ -105,25 +107,26 @@ protected:
 	  * @throws NoInformationException if no inforamtion about the package
 	  * can be retrieved. */
 	QStringList filesForPackage(const string& packageName) throw (NoInformationException);
-	/** @brief Returns if we have a single file for the filelist of the package.
-	  *
-	  * I.e. it is fast accessible. 
-	  */
-	bool hasFastFilelist(const string& packageName);
+	/** @brief File info for the file containing the list of installed files for the package. 
+	 * 
+	 * I first looks for the file in /var/lib/dpkg/info/<em>packagename</em> without 
+	 * any arch extension, then for any file
+	 * with an arbitrary extension (returns the first match).
+	 * Returns an empty QFileInfo if the package is not installed (i.e. no list file is
+	 * available). 
+	 */
+	QFileInfo getFileListFileName(const string& packageName);
 	/** @brief Returns if the given package is installed.
-	  *
-	  * The method checks if /var/lib/dpkg/info/<em>packagename</em>.md5sums is available
-	  * to determine the installed state.
 	  */
 	bool isInstalled(const string& packageName);
 	/** This checks if the apt-file system is available. */
 	bool aptFileAvailable();
-protected slots:
+protected Q_SLOTS:
 	/** @brief Slot that calls clearSearch() */
 	void onClearSearch()	{ clearSearch(); };
 	/** @brief Evaluates the currently entered search. */
 	void evaluateSearch();
-private slots:
+private Q_SLOTS:
 	/** This is called whenever the text of the widget where to insert the 
 	  * search pattern changes. */
 	void onInputTextChanged(const QString&);
