@@ -12,6 +12,9 @@
 
 #include <iprovider.h>
 
+#include <globals.h>
+#include <helpers.h>
+
 #include "orphanplugincontainer.h"
 
 #include "orphanpluginfactory.h"
@@ -26,7 +29,7 @@ extern "C"
 	
 	NPlugin::PluginInformation get_pluginInformation()
 	{
-		return NPlugin::PluginInformation("orphanplugin", "2.4", "Benjamin Mesing");
+		return NPlugin::PluginInformation("orphanplugin", toString(NPackageSearch::VERSION), "Benjamin Mesing");
 	} 
 }
 
@@ -42,6 +45,7 @@ OrphanPluginContainer::OrphanPluginContainer()
 
 OrphanPluginContainer::~OrphanPluginContainer()
 {
+	unloadAllPlugins();
 }
 
 
@@ -61,7 +65,7 @@ bool OrphanPluginContainer::init(IProvider* pProvider)
 				"The orphan plugin was disabled. "
 				"To use the orphan plugin install the deborphan package via<br>"
 				"<tt>apt-get install deborphan</tt><br>" 
-				"and reenable the plugin using <i>Plugins -> Control Plugins</i> afterwards."
+				"and reenable the plugin using <i>Packagesearch -> Control Plugins</i> afterwards."
 			)
 		);
 		return false;
