@@ -6,7 +6,6 @@
 #include <QObject>
 #include <QString>
 
-#include <ept/popcon/popcon.h>
 //#include <ept/configuration/apt.h>
 
 #include <baseplugincontainer.h>
@@ -33,8 +32,6 @@ class PopconPluginContainer : public QObject, public BasePluginContainer
 {
 	Q_OBJECT
 	
-	typedef ept::popcon::Popcon Popcon;
-
 	/** @brief This holds if the popcon operations are currently enabled. 
 	  * 
 	  * This will be set to false if the reading of the tag database failed. 
