@@ -57,6 +57,11 @@ public:
 	/** @brief This returns always true as I do not see a way to get hold of the exit status using an xterm. */
 	virtual bool processExitedSuccessful() const	{ return true; };
 	virtual void setTitle(const QString& title);
+	/** @see RunCommand::waitForFinished()
+	  * @pre a process must be started
+	  */
+	virtual bool waitForFinished(int msecs = 30000 );
+	virtual bool finished();
 };
 
 };	// namespace NApplication
