@@ -304,9 +304,8 @@ Nach Wortgruppen kann gesucht werden, indem diese in Anführungsstriche gesetzt
         <translation>Beschreibung</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="189"/>
         <source>&lt;h3&gt;Package not found&lt;/h3&gt;&lt;p&gt;Could not find a valid description for the package &lt;b&gt;</source>
-        <translation>&lt;h3&gt;Paket nicht gefunden&lt;/h3&gt;&lt;p&gt;Für das Paket &lt;b&gt;</translation>
+        <translation type="obsolete">&lt;h3&gt;Paket nicht gefunden&lt;/h3&gt;&lt;p&gt;Für das Paket &lt;b&gt;</translation>
     </message>
     <message>
         <source>&lt;/b&gt; in the database.&lt;br&gt;This could mean either that you have selected a virtual package or that the package description  was not found for an unknown reason. It is possible that your debtags and apt database are out of sync. Try running &lt;tt&gt;debtags update&lt;/tt&gt; and &lt;tt&gt;apt-get update&lt;/tt&gt; as root.&lt;/p&gt;</source>
@@ -318,9 +317,23 @@ Nach Wortgruppen kann gesucht werden, indem diese in Anführungsstriche gesetzt
         <translation>Plugin für Paketbeschreibungen</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="191"/>
         <source>&lt;/b&gt; in the database.&lt;br&gt;This could mean either that you have selected a virtual package or that the package description  was not found for an unknown reason.&lt;/p&gt;</source>
-        <translation> konnte keine gültige Beschreibung in der Datenbank gefunden werden. &lt;br&gt;Dies bedeutet entweder dass ein virtuelles Paket ausgewählt wurde oder dass die Paketbeschreibung aus einem anderen Grund nicht gefunden werden konnte. &lt;/p&gt;</translation>
+        <translation type="obsolete"> konnte keine gültige Beschreibung in der Datenbank gefunden werden. &lt;br&gt;Dies bedeutet entweder dass ein virtuelles Paket ausgewählt wurde oder dass die Paketbeschreibung aus einem anderen Grund nicht gefunden werden konnte. &lt;/p&gt;</translation>
+    </message>
+    <message>
+        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="189"/>
+        <source>&lt;h3&gt;Package not found&lt;/h3&gt;&lt;p&gt;Could not find a valid description for &lt;b&gt;</source>
+        <translation>&lt;h3&gt;Paket nicht gefunden&lt;/h3&gt;&lt;p&gt;Für das Paket &lt;b&gt;</translation>
+    </message>
+    <message>
+        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="191"/>
+        <source>&lt;/b&gt;.&lt;br&gt;</source>
+        <translation>konnte keine Beschreibung gefunden werden.&lt;br&gt;</translation>
+    </message>
+    <message>
+        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="192"/>
+        <source>This could mean either that you have selected a virtual package or that the package description  was not found for an unknown reason.&lt;/p&gt;</source>
+        <translation>Dies bedeutet entweder dass ein virtuelles Paket ausgewählt wurde oder dass die Paketbeschreibung aus einem anderen Grund nicht gefunden werden konnte.&lt;/p&gt;</translation>
     </message>
     <message>
         <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="217"/>
@@ -415,12 +428,12 @@ Nach Wortgruppen kann gesucht werden, indem diese in Anführungsstriche gesetzt
     <message>
         <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="271"/>
         <source>&lt;b&gt;Recommends:&lt;/b&gt; </source>
-        <translation>&lt;b&gt;Empfiehlt&lt;/b&gt;: </translation>
+        <translation>&lt;b&gt;Empfiehlt:&lt;/b&gt; </translation>
     </message>
     <message>
         <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="276"/>
         <source>&lt;b&gt;Suggests:&lt;/b&gt; </source>
-        <translation>&lt;b&gt;Schlägt vor&lt;/b&gt;: </translation>
+        <translation>&lt;b&gt;Schlägt vor:&lt;/b&gt; </translation>
     </message>
     <message>
         <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="281"/>
@@ -458,6 +471,11 @@ Nach Wortgruppen kann gesucht werden, indem diese in Anführungsstriche gesetzt
         <source>&lt;b&gt;Conffiles&lt;/b&gt;: </source>
         <translation>&lt;b&gt;Konfigurationsdateien&lt;/b&gt;: </translation>
     </message>
+    <message>
+        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="298"/>
+        <source>&lt;b&gt;Homepage&lt;/b&gt;: &lt;a HREF=&apos;</source>
+        <translation></translation>
+    </message>
     <message>
         <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="288"/>
         <source>&lt;b&gt;Size&lt;/b&gt;: </source>
